CustomInfo class

Constructors

CustomInfo(String name, {bool ignoreStderr = false, bool useStderr = false, Set<CustomInfoPlatforms> platforms = const {CustomInfoPlatforms.linux, CustomInfoPlatforms.macos, CustomInfoPlatforms.windows}, String? platformDefaultValue})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreStderr → bool
Ignore message in stderr when running command. This flag is useful when running command that prints warning message to stderr.
final
name → String
Output variable name.
final
platformDefaultValue → String?
Set the default value for command result on platforms that not available.
final
platforms → Set<CustomInfoPlatforms>
Specify only run current command on which compile platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useStderr → bool
Use output int stderr as command result. This flag also will see command running succeed if stderr has message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited